@@ -18,7 +18,7 @@ jQuery(document).ready(function() {
         */
         // auto-select input fields
         jQuery('.tag-embed-code input').focus(function(event) {event.target.select();});
-        ImageTags.prepareEmbedOptions()
+        ImageTags.prepareEmbedOptions();
     }
 
 });
@@ -73,7 +73,7 @@ ImageTags = {
         // Bind click event to a.tag-link-plain to disable real links
         ImageTags.preventRealLink(jQuery('.tag-link-plain'));
         // Hide save button and allow multi submit
-        form.find('input.submit-widget').hide().addClass('allowMultiSubmit')
+        form.find('input.submit-widget').hide().addClass('allowMultiSubmit');
     },
     
     
@@ -127,8 +127,7 @@ ImageTags = {
     turnRemovable: function(collection) {
         /* Turn collection into removable (i.e. bind click event)
          */
-        //collection.click(ImageTags.onRemoveLinkClick);
-        collection.live('click', ImageTags.onRemoveLinkClick);
+        collection.click(ImageTags.onRemoveLinkClick);
     },
     
     createActionLinks: function(collection) {
@@ -169,7 +168,7 @@ ImageTags = {
         var newX = ui.position.left + box.width()/2;
         var newY = ui.position.top + box.height()/2;
         // Calculate real final position (0%<=position<=100%)
-        var finalPosition = {}
+        var finalPosition = {};
         if(newX<0) {
             newX = 0;
             finalPosition['left'] = (newX - box.width()/2) + 'px';
@@ -197,7 +196,6 @@ ImageTags = {
         var id = box.attr('id').replace('image-tag-', '').replace('-', '.');
         var title = box.find('.tag-link-title').text();
         var url = box.attr('href') || '';
-        var form = jQuery('#ajax-form form');
         var data = {'x': perX, 'y': perY, 'id': id, 'title': title, 'url': url, 'ajax': 1};
         // Pre-load form (invisibly) to be submitted.
         ImageTags.loadForm(data);
@@ -235,7 +233,7 @@ ImageTags = {
         var wrapper = box.closest('.tag-image-wrapper');
         var wWidth = wrapper.width();
         var wHeight = wrapper.height();
-        var position = box.position()
+        var position = box.position();
         var newX = position.left /*- offsetW.left*/ + box.width()/2;
         var newY = position.top /*- offsetW.top*/ + box.height()/2;
         // Translate X,Y into percentages
@@ -270,21 +268,29 @@ ImageTags = {
         event.stopPropagation();
         // Call to confirm dialog
         var confirmDiv = jQuery('#imagetags-confirm-remove');
+        // Set removeLink href to confirmDiv data. This is because of some issue with jquery 1.3.2 (Plone 3)
+        confirmDiv.data('removeLinkURL', event.target.href);
         
-        var buttons = {}
+        var buttons = {};
         buttons[ImageTagsLabels.noButtonText] = function() {
             jQuery(this).dialog('close');
         };
         buttons[ImageTagsLabels.yesButtonText] = function() {
             jQuery(this).dialog('close');
-            jQuery.get(event.target.href, ImageTags.onRemoveSuccess);
+            var confirmDiv = jQuery('#imagetags-confirm-remove')
+            var removeLinkURL = confirmDiv.data('removeLinkURL');
+            confirmDiv.data('removeLinkURL', null)
+            jQuery.get(removeLinkURL, ImageTags.onRemoveSuccess);
         };
+        // Separate dialog open in two lines due to some issue with jquery-ui 1.7.2 (Plone 3)
         confirmDiv.dialog({
+            autoOpen: false,
             title: ImageTagsLabels.removeLinkText,
             resizable: false,
             buttons: buttons,
             modal: true
-        })
+        });
+        confirmDiv.dialog('open');
     },
 
     onRealLinkClick: function(event) {
@@ -339,15 +345,18 @@ ImageTags = {
         // Display the form dialog
         buttons = {};
         buttons[ImageTagsLabels.saveButtonText] = ImageTags.submitForm;
+        // Separate dialog open in two lines due to some issue with jquery-ui 1.7.2 (Plone 3)
         formContainer.dialog({
             title: ImageTagsLabels.tagFormTitle, 
             resizable: false,
             close: onclose,
             open: function(event, ui) {
-                jQuery(this).find('input[type!=hidden]').first().focus();
+                jQuery(this).find('input[type!=hidden]:first').focus();
             },
             buttons: buttons
         });
+        formContainer.dialog('open');
+        
     },
     
     submitForm: function(event) {
@@ -390,7 +399,7 @@ ImageTags = {
         jQuery('#ajax-form').dialog('close');
         ImageTags.resetForm();
         // Take the response data and show/update boxes or tags
-        var root = jQuery(request.responseXML.documentElement);
+        var root = request ? jQuery(request.responseXML.documentElement) : jQuery(data.documentElement);
         var id = root.attr('id');
         var boxHTML = root.find('box');
         var titleHTML = root.find('title');
@@ -402,10 +411,11 @@ ImageTags = {
             plainTags = jQuery('#image-tag-plain-' + safeId).replaceWith(titleHTML.text());
         } else {
             // Create a new tag-link box and turn it into draggable
-            ImageTags.turnDraggable(jQuery('.tag-image-wrapper').append(boxHTML.text()).children().last());
+            jQuery('.tag-image-wrapper').append(boxHTML.text());
+            ImageTags.turnDraggable(jQuery('#image-tag-' + safeId));
             // Create the new tag-plain link
             plainTags = jQuery('.tag-plain-tags');
-            plainTags.append((plainTags.children().length > 0 ? ImageTagsLabels.hyphenLabel : '') + titleHTML.text());
+            plainTags.append((plainTags.children().length > 0 ? '<span class="tag-hyphen">' + ImageTagsLabels.hyphenLabel + '</span>': '') + titleHTML.text());
             plainTags.show().parent().find('.tag-plain-no-tag').hide();
         }
         // Modify events of newly created elements in the page
@@ -413,7 +423,7 @@ ImageTags = {
         ImageTags.preventRealLink(jQuery('#image-tag-link-plain-' + safeId));
         ImageTags.createActionLinks(jQuery('#image-tag-link-plain-' + safeId));
         ImageTags.turnEditable(jQuery('#image-tag-plain-' + safeId + ' .tag-edit'));
-        //ImageTags.turnRemovable(jQuery('#image-tag-plain-' + safeId + ' .tag-remove'));
+        ImageTags.turnRemovable(jQuery('#image-tag-plain-' + safeId + ' .tag-remove'));
 
     },
     
@@ -421,16 +431,24 @@ ImageTags = {
         /* Called after removal success
          */
 
-        // Get the removed box/label and remove them
-        var json = data;
+        // Get the removed box/label and remove them (together with corresponding hyphens)
+        var json = data.removed ? data : eval('(' + data + ')');
         var removed = json.removed;
         jQuery.each(removed, function(pos, id) {
             var safeId = id.replace('.', '-');
-            jQuery('#image-tag-' + safeId + ', #image-tag-plain-' + safeId).remove();
+            jQuery('#image-tag-' + safeId).remove();
+            var plainTag = jQuery('#image-tag-plain-' + safeId);
+            if(plainTag.prev().length===0) {
+                plainTag.next().remove();
+            } else {
+                plainTag.prev().remove();
+            }
+            plainTag.remove();
         });
-        // Once removed, re-write tag-list with the corresponding hyphens.
         var plainTags = jQuery('.tag-plain-tags');
-        var children = plainTags.children().clone(true);
+        // Once removed, re-write tag-list with the corresponding hyphens.
+        
+/*        var children = plainTags.children().clone(true);
         plainTags.empty();
         children.each(function(pos, el) {
             plainTags.append(el);
@@ -438,8 +456,9 @@ ImageTags = {
                 plainTags.append(ImageTagsLabels.hyphenLabel);
             }
         });
+*/
         // If all labels were removed, show "No tags yet" legend.
-        if(children.length==0) {
+        if(plainTags.children().length===0) {
             plainTags.hide().parent().find('.tag-plain-no-tag').show();
 
         }
@@ -463,8 +482,8 @@ ImageTags = {
         var code = jQuery('.tag-embed-code').removeClass('tag-embed-code').addClass('tag-embed-code-dyn');
         var dd = code.find('dd');
         var labels = code.find('label').hide();
-        var inputs = code.find('input').hide();
-        var brs = code.find('br').remove();
+        code.find('input').hide();
+        code.find('br').remove();
         labels.each( function(idx, val) {
             var text = jQuery(val).text();
             dd.prepend('<label for="tag-embed-label-' + text + '"><input type="radio" class="radio" name="tag-embed-choice" id="tag-embed-label-' + text + '" value="' + text + '"/>' + text + '</label>');
@@ -475,9 +494,10 @@ ImageTags = {
         });
         // When clicking radio buttons, replace textarea value with matching hidden input fields
         code.find('input[type=radio]').click(function(event) {
-            jQuery('#tag-embed-textarea').attr('value', code.find('#' + event.target.id.replace('-label-', '-code-')).first().attr('value')).select();
-        }).first().click();
-
+            jQuery('#tag-embed-textarea').attr('value', code.find('#' + event.target.id.replace('-label-', '-code-')).attr('value')).select();
+        });
+        // Pre-select first option
+        code.find('input[type=radio]:first').click();
     }
     
 };
